==> mx-service-manager_25.08.05.tar.xz: BUILD/translations/mx-service-manager_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="70"/>
        <source>Administrator Access Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="71"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/mainwindow.cpp" line="378"/>
        <source>MX Service Manager</source>
        <translation>Gestor de serviços do MX</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="26"/>
        <location filename="../src/mainwindow.cpp" line="160"/>
        <location filename="../src/mainwindow.cpp" line="394"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Ativar no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Sobre...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="125"/>
        <source>Display help </source>
        <translation>Mostrar ajuda </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="128"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="166"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="169"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="175"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="216"/>
        <location filename="../src/mainwindow.cpp" line="142"/>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="230"/>
        <location filename="../src/mainwindow.cpp" line="322"/>
        <source>All services</source>
        <translation>Todos os serviços</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="235"/>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>Running services</source>
        <translation>Serviços em execução</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="240"/>
        <location filename="../src/mainwindow.cpp" line="324"/>
        <source>Services enabled at boot</source>
        <translation>Serviços ativados no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="245"/>
        <location filename="../src/mainwindow.cpp" line="325"/>
        <source>Services disabled at boot</source>
        <translation>Serviços desativados no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="281"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="291"/>
        <location filename="../src/mainwindow.cpp" line="71"/>
        <location filename="../src/mainwindow.cpp" line="79"/>
        <location filename="../src/mainwindow.cpp" line="83"/>
        <source>Loading...</source>
        <translation>A carregar...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="310"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Esta ferramenta lista os serviços e daemons (processos que são executados em segundo plano) encontrados neste sistema. Tenha cuidado para evitar parar algo que possa perturbar um componente crítico; é melhor não o interromper se não souber o que é.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="65"/>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <location filename="../src/mainwindow.cpp" line="426"/>
        <location filename="../src/mainwindow.cpp" line="435"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="66"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Não foi possível determinar o sistema de inicialização. Este programa deve ser executado com o sistema de inicialização ‘SystemD’ ou ‘SysVinit’</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="147"/>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>S&amp;tart</source>
        <translation>&amp;Iniciar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="153"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Desativar no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="358"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation>%1 serviços no total, %2 &lt;font color=&apos;%3&apos;&gt;em execução&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="363"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation>%1 &lt;font color=&apos;%2&apos;&gt;ativado(s)&lt;/font&gt; no arranque, mas não em execução</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="378"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="379"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="380"/>
        <source>Service and daemon manager</source>
        <translation>Gestor de serviços e processos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="382"/>
        <source>Copyright (c) MX Linux</source>
        <translation> Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="383"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Could not enable %1</source>
        <translation>Não foi possível ativar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="400"/>
        <location filename="../src/mainwindow.cpp" line="407"/>
        <location filename="../src/mainwindow.cpp" line="431"/>
        <location filename="../src/mainwindow.cpp" line="440"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="400"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 foi ativado no momento do arranque.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <source>Could not disable %1</source>
        <translation>Não foi possível desativar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="407"/>
        <source>%1 was disabled.</source>
        <translation>%1 estava desativado.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="415"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="426"/>
        <source>Could not start %1</source>
        <translation>Não foi possível iniciar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="431"/>
        <source>%1 was started.</source>
        <translation>%1 foi iniciado.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="435"/>
        <source>Could not stop %1</source>
        <translation>Não foi possível parar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="440"/>
        <source>%1 was stopped.</source>
        <translation>%1 foi interrompido.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <location filename="../src/main.cpp" line="89"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que tem sessão iniciada como root, por favor termine a sessão e volte a entrar como utilizador normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="90"/>
        <source>You must run this program with admin access.</source>
        <translation>Deve executar este programa como administrador.</translation>
    </message>
    <message>
        <location filename="../src/service.cpp" line="150"/>
        <source>Could not find service description</source>
        <translation>Não foi possível encontrar a descrição do serviço</translation>
    </message>
</context>
</TS>

==> mx-service-manager_25.08.06.tar.xz: BUILD/translations/mx-service-manager_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="70"/>
        <source>Administrator Access Required</source>
        <translation>É necessário ter permissões de administrador</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="71"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Esta operação requer  permissões de administrador. Reinicie o programa e digite a sua senha quando esta for solicitada.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/mainwindow.cpp" line="378"/>
        <source>MX Service Manager</source>
        <translation>Gestor de serviços do MX</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="26"/>
        <location filename="../src/mainwindow.cpp" line="160"/>
        <location filename="../src/mainwindow.cpp" line="394"/>
        <source>&amp;Enable at boot</source>
        <translation>&amp;Ativar no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="62"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="65"/>
        <source>&amp;About...</source>
        <translation>&amp;Sobre...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="71"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="125"/>
        <source>Display help </source>
        <translation>Mostrar ajuda </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="128"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="134"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="166"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="169"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="175"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="216"/>
        <location filename="../src/mainwindow.cpp" line="142"/>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="230"/>
        <location filename="../src/mainwindow.cpp" line="322"/>
        <source>All services</source>
        <translation>Todos os serviços</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="235"/>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>Running services</source>
        <translation>Serviços em execução</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="240"/>
        <location filename="../src/mainwindow.cpp" line="324"/>
        <source>Services enabled at boot</source>
        <translation>Serviços ativados no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="245"/>
        <location filename="../src/mainwindow.cpp" line="325"/>
        <source>Services disabled at boot</source>
        <translation>Serviços desativados no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="281"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="291"/>
        <location filename="../src/mainwindow.cpp" line="71"/>
        <location filename="../src/mainwindow.cpp" line="79"/>
        <location filename="../src/mainwindow.cpp" line="83"/>
        <source>Loading...</source>
        <translation>A carregar...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="310"/>
        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
        <translation>Esta ferramenta lista os serviços e daemons (processos que são executados em segundo plano) encontrados neste sistema. Tenha cuidado para evitar parar algo que possa perturbar um componente crítico; é melhor não o interromper se não souber o que é.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="65"/>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <location filename="../src/mainwindow.cpp" line="426"/>
        <location filename="../src/mainwindow.cpp" line="435"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="66"/>
        <source>Could not determine the init system. This program is supposed to run either with systemd or sysvinit</source>
        <translation>Não foi possível determinar o sistema de inicialização. Este programa deve ser executado com o sistema de inicialização ‘SystemD’ ou ‘SysVinit’</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="147"/>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>S&amp;tart</source>
        <translation>&amp;Iniciar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="153"/>
        <source>&amp;Disable at boot</source>
        <translation>&amp;Desativar no arranque</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="358"/>
        <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
        <translation>%1 serviços no total, %2 &lt;font color=&apos;%3&apos;&gt;em execução&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="363"/>
        <source>%1 &lt;font color=&apos;%2&apos;&gt;enabled&lt;/font&gt; at boot, but not running</source>
        <translation>%1 &lt;font color=&apos;%2&apos;&gt;ativado(s)&lt;/font&gt; no arranque, mas não em execução</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="378"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="379"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="380"/>
        <source>Service and daemon manager</source>
        <translation>Gestor de serviços e processos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="382"/>
        <source>Copyright (c) MX Linux</source>
        <translation> Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="383"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <source>Could not enable %1</source>
        <translation>Não foi possível ativar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="400"/>
        <location filename="../src/mainwindow.cpp" line="407"/>
        <location filename="../src/mainwindow.cpp" line="431"/>
        <location filename="../src/mainwindow.cpp" line="440"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="400"/>
        <source>%1 was enabled at boot time.</source>
        <translation>%1 foi ativado no momento do arranque.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <source>Could not disable %1</source>
        <translation>Não foi possível desativar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="407"/>
        <source>%1 was disabled.</source>
        <translation>%1 estava desativado.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="415"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="426"/>
        <source>Could not start %1</source>
        <translation>Não foi possível iniciar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="431"/>
        <source>%1 was started.</source>
        <translation>%1 foi iniciado.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="435"/>
        <source>Could not stop %1</source>
        <translation>Não foi possível parar %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="440"/>
        <source>%1 was stopped.</source>
        <translation>%1 foi interrompido.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="81"/>
        <location filename="../src/main.cpp" line="89"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Parece que tem sessão iniciada como root, por favor termine a sessão e volte a entrar como utilizador normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="90"/>
        <source>You must run this program with admin access.</source>
        <translation>Deve executar este programa como administrador.</translation>
    </message>
    <message>
        <location filename="../src/service.cpp" line="150"/>
        <source>Could not find service description</source>
        <translation>Não foi possível encontrar a descrição do serviço</translation>
    </message>
</context>
</TS>
